==> haskell-gtk-sni-tray-0.1.8.1-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-sni-tray
version:              0.1.8.1
visibility:           public
id:                   gtk-sni-tray-0.1.8.1-M6aXHl2CdE3HzOa3dNvEP
key:                  gtk-sni-tray-0.1.8.1-M6aXHl2CdE3HzOa3dNvEP
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:             A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:             System
abi:                  7a5e06389e6bdadf18fae296a315b67f
exposed:              True
exposed-modules:      StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:       Paths_gtk_sni_tray
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-sni-tray
hs-libraries:         HSgtk-sni-tray-0.1.8.1-M6aXHl2CdE3HzOa3dNvEP
extra-libraries:
    gtk-3 gdk-3 z harfbuzz pangocairo-1.0 pango-1.0 atk-1.0 cairo
    cairo-gobject gdk_pixbuf-2.0 gio-2.0 glib-2.0 gobject-2.0

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/atk-1.0
    /usr/include/freetype2 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/harfbuzz
    /usr/include/libmount /usr/include/blkid /usr/include/libpng16
    /usr/include/pixman-1 /usr/include/cloudproviders
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/dbus-1.0 /usr/lib/dbus-1.0/include
    /usr/include/fribidi /usr/include/sysprof-6
    /usr/include/gio-unix-2.0

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dbus-1.3.1-tY8Z7VH26oFh6ncQIgtHo directory-1.3.6.2
    enclosed-exceptions-1.0.3-75g9Ic3Xpr56x1zMhBaOTf filepath-1.4.2.2
    gi-cairo-1.0.29-7UvfO9ymdgp6qiNwaQWoZZ
    gi-cairo-connector-0.1.1-GQ2lTYvNb2v8aFMUdQOs3F
    gi-cairo-render-0.1.2-Hpw7kHnw7ZZM9DVNqIcx7
    gi-dbusmenugtk3-0.4.14-5z3RmDeAvmNEFPo1yN3TyJ
    gi-gdk-3.0.25-Ci0TLn0FFf4GASPFl1VDaR
    gi-gdkpixbuf-2.0.31-AnehPyaBQOt3rIl3ZFH6Hf
    gi-glib-2.0.29-9vHBYyAzl8UNImBC3bd6A
    gi-gtk-3.0.38-CuVyyWSKsK2nULYcMLtsF
    gtk-strut-0.1.3.2-Hmw4wf9I7P527A0c0cS9xZ
    haskell-gi-0.26.7-BSu5JkEPnW352SEU9hXyJj
    haskell-gi-base-0.26.4-BFXyyduHPGW6bU8MlEazkc
    hslogger-1.3.1.1-PsgAnGYwLpGoMJ69FDKNX
    status-notifier-item-0.3.1.0-Fy0g1UNOIbMsKgC7flYpk text-1.2.5.0
    transformers-0.5.6.2 transformers-base-0.4.6-4mLyiZ1lYe32soo1Zji4lM
    unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:         /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-sni-tray-0.1.8.1-185-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-sni-tray
version:              0.1.8.1
visibility:           public
id:                   gtk-sni-tray-0.1.8.1-JIW5YUuuH0WHt812l6NlHI
key:                  gtk-sni-tray-0.1.8.1-JIW5YUuuH0WHt812l6NlHI
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:             A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:             System
abi:                  a7429871f2690daed3e901674ee41a31
exposed:              True
exposed-modules:      StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:       Paths_gtk_sni_tray
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-sni-tray
hs-libraries:         HSgtk-sni-tray-0.1.8.1-JIW5YUuuH0WHt812l6NlHI
extra-libraries:
    gtk-3 gdk-3 z harfbuzz pangocairo-1.0 pango-1.0 atk-1.0 cairo
    cairo-gobject gdk_pixbuf-2.0 gio-2.0 glib-2.0 gobject-2.0

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/atk-1.0
    /usr/include/freetype2 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/harfbuzz
    /usr/include/libmount /usr/include/blkid /usr/include/libpng16
    /usr/include/pixman-1 /usr/include/cloudproviders
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/dbus-1.0 /usr/lib/dbus-1.0/include
    /usr/include/fribidi /usr/include/sysprof-6
    /usr/include/gio-unix-2.0

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dbus-1.3.1-7kPkeSNrOyWCF8zq1bOiib directory-1.3.6.2
    enclosed-exceptions-1.0.3-LC9E6UjZ03g8kSVD1tcOIl filepath-1.4.2.2
    gi-cairo-1.0.29-8nl3Y8KVDNKD3am6rfIttB
    gi-cairo-connector-0.1.1-C3nbnmPsmjQGJMcfAbmtKk
    gi-cairo-render-0.1.2-Hpw7kHnw7ZZM9DVNqIcx7
    gi-dbusmenugtk3-0.4.14-JThZPLDA5sxLL8J71A67L4
    gi-gdk-3.0.25-7UBB4kHNBkY5Y27J7BV5B8
    gi-gdkpixbuf-2.0.31-BEF3u3e1x1C3iDFwKK0zi3
    gi-glib-2.0.29-8IFaXnO1wvI3Hj7bFh0KOb
    gi-gtk-3.0.38-4wXHY6xVPTh74fHNC1t9gi
    gtk-strut-0.1.3.2-7edT7qpwsBaI3ighyzl8bx
    haskell-gi-0.26.7-8j1XebNL1dJ5d0fTdjt0Iv
    haskell-gi-base-0.26.4-BFXyyduHPGW6bU8MlEazkc
    hslogger-1.3.1.1-5sJBb9bTl31Kj4aoScK1Y3
    status-notifier-item-0.3.1.0-FjHuQaOWe5xA9IbFWosgG text-1.2.5.0
    transformers-0.5.6.2 transformers-base-0.4.6-49q3ABY5SL9GSCeyTZR1jM
    unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:         /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
